@@ -26,7 +26,7 @@ from ..openorders import OpenOrders
 
 class CollateralCalculator(metaclass=abc.ABCMeta):
     def __init__(self) -> None:
-        self.logger: logging.Logger = logging.getLogger(self.__class__.__name__)
+        self._logger: logging.Logger = logging.getLogger(self.__class__.__name__)
 
     def calculate(self, account: Account, all_open_orders: typing.Dict[str, OpenOrders], group: Group, cache: Cache) -> InstrumentValue:
         raise NotImplementedError("CollateralCalculator.calculate() is not implemented on the base type.")
